Cross platform nagios plugins
=============================

These cross platform plugins rely on Python to attain that cross platform
ability.  This means that they are more expensive to run than the compiled
programs from the Nagios-plugins repository.

